@@ -14,7 +14,7 @@ import tempfile
 
 from os import path
 
-VERSION = '0.1.1'
+VERSION = '0.2.0'
 
 class Dotlink(object):
     """Copy or symlink dotfiles from a profile repository to a new location,
@@ -90,7 +90,44 @@ class Dotlink(object):
 
         return log
 
+    @staticmethod
+    def parse_mapping(filename):
+        """Do a simple parse of the dotfile mapping, using semicolons to
+        separate source file name from the target file paths."""
+        mapping_re = r'^("[^"]+"|\'[^\']+\'|[^\'":]+)\s*(?::\s*(.*)\s*)?$'
+        mapping_re = re.compile(mapping_re)
+        dotfiles = {}
+        lineno = 0
+
+        with open(filename) as fh:
+            for line in fh:
+                lineno += 1
+                content = line.strip()
+
+                if not content or content.startswith('#'):
+                    # comment line or empty line
+                    continue
+
+                match = mapping_re.match(content)
+                if match:
+                    source_path, target_path = match.groups()
+                    source_path = source_path.strip('\'"')
+
+                    if source_path in dotfiles:
+                        log.warning('Duplicate dotfile source "%s" on line #%d',
+                                    lineno)
+                        continue
+
+                    dotfiles[source_path] = target_path
+
+                else:
+                    log.warning('Dotfile mapping regex failed on line #%d',
+                                lineno)
+
+        return dotfiles
+
     def sh(self, *command, **kwargs):
+        """Run a shell command with the given arguments."""
         self.log.debug('shell: %s', ' '.join(command))
         return subprocess.check_call(' '.join(command), stdout=sys.stdout,
                                                         stderr=sys.stderr,
@@ -98,6 +135,7 @@ class Dotlink(object):
                                                         shell=True, **kwargs)
 
     def ssh(self, *command):
+        """Run an ssh command using the configured user/server values."""
         if self.args.user:
             ssh_spec = '{0}@{1}'.format(self.args.user, self.args.server)
         else:
@@ -106,6 +144,7 @@ class Dotlink(object):
         return self.sh('ssh', ssh_spec, *command)
 
     def scp(self, local_file, remote_path=''):
+        """Copy a local file to the given remote path."""
         if self.args.user:
             upload_spec = '{0}@{1}:{2}'.format(self.args.user,
                                                self.args.server,
@@ -120,6 +159,7 @@ class Dotlink(object):
         self.log = Dotlink.setup_logger(self.args)
 
     def run(self):
+        """Start the dotfile deployment process."""
         script = path.realpath(__file__)
         self.log.debug('Running from %s with arguments: %s', script, self.args)
 
@@ -136,28 +176,26 @@ class Dotlink(object):
             self.log.exception('Profile deploy failed')
 
     def load_dotfiles(self):
-        import yaml # do this here so that setup.py can import dotlink.VERSION
-
+        """Read in the dotfile mapping as a dictionary."""
         if self.args.map and path.exists(self.args.map):
             dotfiles_path = self.args.map
         else:
             # try finding it in the source directory
-            dotfiles_path = path.join(self.source, 'dotfiles.yaml')
+            dotfiles_path = path.join(self.source, 'dotfiles')
 
         self.log.debug('Loading dotfile mapping from %s', dotfiles_path)
 
-        with open(dotfiles_path) as fh:
-            dotfiles = yaml.load(fh)
-            self.log.debug('Found %d dotfile mappings', len(dotfiles))
-            return dotfiles
+        return Dotlink.parse_mapping(dotfiles_path)
 
     def deploy_dotfiles(self, dotfiles):
+        """Deploy dotfiles using the appropriate method."""
         if self.args.server:
             return self.deploy_remote(dotfiles)
         else:
             return self.deploy_local(dotfiles)
 
     def deploy_remote(self, dotfiles):
+        """Deploy dotfiles to a remote server."""
         try:
             tempdir_path = tempfile.mkdtemp()
             self.log.debug('Deploying to temp dir %s', tempdir_path)
@@ -188,6 +226,7 @@ class Dotlink(object):
                 os.unlink(tempfile_path)
 
     def deploy_local(self, dotfiles, target_root=None):
+        """Deploy dotfiles to a local path."""
         if target_root == None:
             target_root = self.args.path
 
